@@ -7,7 +7,7 @@ PDL::LiteF - minimum PDL module function loader
 Loads the smallest possible set of modules for
 PDL to work, making the functions available in
 the current namespace. If you want something even
-smaller see the L<PDL::Lite> module.
+smaller see the L<PDL::Lite|PDL::Lite> module.
 
 =head1 SYNOPSIS
 
@@ -21,15 +21,12 @@ smaller see the L<PDL::Lite> module.
    use PDL::Slices;
    use PDL::Bad;
    use PDL::Version;
-   use PDL::Lvalue;
 
 =cut
 
 # get the version: 
 use PDL::Version;
-
-package PDL::LiteF;
-$VERSION = $PDL::Version::VERSION;
+$PDL::LiteF::VERSION = $PDL::Version::VERSION;
 
 
 # Load the fundamental PDL packages, with imports
@@ -48,7 +45,6 @@ use PDL::Ufunc;
 use PDL::Basic;
 use PDL::Slices;
 use PDL::Bad;
-use PDL::Lvalue;
 
 EOD
 
