@@ -43,10 +43,7 @@ use vars qw/$VERSION %EXPORT_TAGS %DEF_SYNS @ISA/;
 
 require Exporter;
 
-# difference to 0.91 is that added CENTRE/CENTER as default
-# synonymns (patch by Diab Jerius [ #469110 ])
-our $VERSION = '0.92';
-$VERSION = eval $VERSION;
+$VERSION = '0.91';
 
 @ISA = qw(Exporter);
 
@@ -60,17 +57,10 @@ Exporter::export_tags('Func');
 
 # List of default synonyms
 %DEF_SYNS = (
-	     COLOR  => 'COLOUR',
-	     COLOUR => 'COLOR',
-	     CENTER => 'CENTRE',
-	     CENTRE => 'CENTER',
+	     COLOR => 'COLOUR',
+	     COLOUR => 'COLOR'
 	    );
 
-my $default = {
-	       WarnOnMissing => 1,
-	       FullOptions => 1,
-	       DEBUG => 0,
-	      };
 
 =head1 Utility functions
 
@@ -92,9 +82,10 @@ These routines are exported into the callers namespace by default.
 =item parse( \%defaults, \%user_options)
 
 This will parse user options by using the defaults.  The following
-settings are used for parsing: The options are case-sensitive, a
-default synonym table is consulted (see L</Default Synonyms>),
-minimum-matching is turned on, and translation of values is not performed.
+settings are used for parsing: The options can be case-insensitive, a
+default synonym table is consulted (currently just contains a synonym
+for COLOUR), minimum-matching is turned on, translation of values is
+not performed.
 
 A hash (not hash reference) containing the processed options is returned.
 
@@ -144,15 +135,6 @@ sub _parse {
 
 =back
 
-=head2 Default Synonyms
-
-The following default synonyms are available in the non-OO interface:
-
-  COLOR  => COLOUR
-  COLOUR => COLOR
-  CENTER => CENTRE
-  CENTRE => CENTER
-
 =head1 METHODS
 
 The following methods are available to PDL::Options objects.
@@ -185,11 +167,9 @@ sub new {
   $opt->{AutoTranslate}= 1;# Automatically translate options when processing
   $opt->{MinMatchTrans} = 0; # Min matching during translation
   $opt->{CaseSensTrans} = 0; # Case sensitive during translation
-  # Return full options list
-  $opt->{FullOptions} = $default->{FullOptions};
-  # Whether to warn for options that are invalid or not
-  $opt->{WarnOnMissing}= $default->{WarnOnMissing};
-  $opt->{DEBUG}    = $default->{DEBUG};    # Turn on debug messages
+  $opt->{FullOptions} = 1; # Return full options list
+  $opt->{WarnOnMissing}=1; # Whether to warn for options that are invalid or not.
+  $opt->{DEBUG}    = 0;    # Turn on debug messages
 
   # Bless into class
   bless ( $opt, $class);
@@ -200,6 +180,7 @@ sub new {
   return $opt;
 }
 
+
 =item extend (\%options)
 
 This will copy the existing options object and extend it with the
@@ -393,17 +374,6 @@ sub current {
   }
 }
 
-=item clear_current
-
-This routine clears the 'state' of the C<PDL::Options> object so that
-the next call to current will return an empty list
-
-=cut
-
-sub clear_current {
-  my $self = shift;
-  @{$self->{CurrKeys}}=();
-}
 
 
 # Method to set the 'mini' state of the object
@@ -625,13 +595,8 @@ the line.
 
 sub warnonmissing {
   my $self = shift;
-  if (ref $self) {
-    if (@_) { $self->{WarnOnMissing}=shift;}
-    return $self->{WarnOnMissing};
-  } else {
-    $default->{WarnOnMissing} = shift if @_;
-    return $default->{WarnOnMissing};
-  }
+  if (@_) { $self->{WarnOnMissing}=shift;}
+  return $self->{WarnOnMissing};
 }
 
 
@@ -644,13 +609,8 @@ Can be used to set or return this value.
 
 sub debug {
   my $self = shift;
-  if (ref $self) {
-    if (@_) { $self->{DEBUG} = shift; }
-    return $self->{DEBUG};
-  } else {
-    $default->{DEBUG} = shift if @_;
-    return $default->{DEBUG};
-  }
+  if (@_) { $self->{DEBUG} = shift; }
+  return $self->{DEBUG};
 }
 
 
@@ -718,11 +678,11 @@ sub options {
     foreach my $userkey (sort keys %user) {
 
       # Check for matches in the default set
-      my @matched = $self->compare_with_list(0, $userkey, sort keys %base);
+      my @matched = $self->compare_with_list(0, $userkey, keys %base);
 
       # If we had no matches, check the synonyms list
       if ($#matched == -1) {
-	@matched = $self->compare_with_list(0, $userkey, sort keys %syn);
+	@matched = $self->compare_with_list(0, $userkey, keys %syn);
 
 	# If we have matched then convert the key to the actual
 	# value stored in the object
@@ -793,14 +753,14 @@ sub translate {
   # Now need to go through each of the keys
   # and if the corresponding key exists in the translation
   # hash we need to check that a valid translation exists
-  foreach my $key ( sort keys %opt ) {
+  foreach my $key ( keys %opt ) {
     if (exists $trans{$key}) {
       # Okay so a translation might exist
       # Now compare keys in the hash in the hash
       my %subhash = %{$trans{$key}};
 
       my @matched =
-	$self->compare_with_list(1, $opt{$key}, sort keys %subhash);
+	$self->compare_with_list(1, $opt{$key}, keys %subhash);
 
       # At this point we have matched the userkey to a key in the
       # dictionary. If there is no translation dont say anything
@@ -930,7 +890,7 @@ the second uses the object-oriented interface.
 		  }
 		);
 
-This will return a hash containing
+This will return a hash containg
 
     %options = (
                  LINE => 1,
