@@ -1,17 +1,43 @@
+# the following two packages can be used to collect podparser
+# output into a string or simulate a portable null device
+
+package StrHandle;
+
+sub new {
+  my $type = shift;
+  my $this = bless {},$type;
+  $this->{Text} = "";
+  return $this;
+}
+
+sub print {
+  my $this = shift;
+  $this->{Text} .= "@_";
+}
+
+sub text {
+  $_[0]->{Text} .= $_[1] if $#_ > 0;
+  return $_[0]->{Text};
+}
+
+
+package NullHandle;
+
+@ISA = qw/ StrHandle/;
+
+sub print {} # do nothing
+
+
 # the filter for the PDL pod format (which is a valid general perl
 # pod format but with special interpretation of some =for directives)
 
 package PDL::PodParser;
-use strict;
-use warnings;
 use PDL::Core '';
-use Pod::Select;
-use File::Spec;
-use File::Basename;
+use PDL::Pod::Parser;
 
-our @ISA = qw(Pod::Select);
+@ISA = qw(PDL::Pod::Parser);
 
-our %Title = ('Example' => 'Example',
+%Title = ('Example' => 'Example',
 	  'Ref'     => 'Reference',
 	  'Sig'     => 'Signature',
 	  'Opt'     => 'Options',
@@ -20,22 +46,21 @@ our %Title = ('Example' => 'Example',
 	 );
 
 sub new {
-  my $class = shift;
-  my $parser = $class->SUPER::new(@_);
-  bless $parser,$class; # just in case
-
-  $parser->select("METHODS|OPERATORS|CONSTRUCTORS|FUNCTIONS|NAME");
+  my ($type) = @_;
+  my $parser = new PDL::Pod::Parser;
+  $parser->select("FUNCTIONS|NAME");
   $parser->{CURFUNC} = undef;
   $parser->{SYMHASH} = {};
   $parser->{INBLOCK} = 0;
   $parser->{Mode} = "";
   $parser->{verbose} = 0;
   $parser->{NAME} = 'UNKNOWN';
+  bless $parser,$type;
   return $parser;
 }
 
 sub command {
-  my ($this,$cmd,$txt,$line_num,$pod_para) = @_;
+  my ($this,$cmd,$txt,$sep) = @_;
   $this->{Parmode} = 'Body';
 
   if ($cmd eq 'head1') {
@@ -43,41 +68,36 @@ sub command {
     $this->{Parmode} = 'Body';
     $this->{Parmode} = 'NAME' if $txt =~ /NAME/;
   } elsif ($this->{Mode} =~ /NAME/) {
-    # do nothing (was 'last' but that was probably a mistake)
+    last;
   } elsif ($cmd eq 'head2') {
-    return $this->SUPER::command($cmd,$txt,$line_num,$pod_para) if $txt =~ /^The\s/; # heuristic to deal with GSL::CDF descriptive =head2
-    # A function can have multiple names (ex: zeros and zeroes),
-    # so split at the commas
     my @funcs = split(',',$txt);
-    # Remove parentheses (so myfunc and myfunc() both work)
-    my @names = map {$1 if m/\s*([^\s\(]+)\s*/} @funcs;
+    my @names = map {$1 if m/\s*([^\s(]+)\s*/} @funcs;
     barf "error parsing function list '$txt'"
       unless $#funcs == $#names;
     # check for signatures
     my $sym = $this->{SYMHASH};
-    for (@funcs) {
-      $sym->{$1}->{Module} = $this->{NAME} if m/\s*([^\s(]+)\s*/;
-      $sym->{$1}->{Sig} = $2  if m/\s*([^\s(]+)\s*\(\s*(.+)\s*\)\s*$/;
-    }
+    for (@funcs) { $sym->{$1}->{Module} = $this->{NAME}
+		   if m/\s*([^\s(]+)\s*/;
+		   $sym->{$1}->{Sig}=$2
+		     if m/\s*([^\s(]+)\s*\(\s*(.+)\s*\)\s*$/}
     # make the first one the current function
     $sym->{$names[0]}->{Names} = join(',',@names) if $#names > 0;
     my $name = shift @names;
-    # Make the other names cross-reference the first name
-    $sym->{$_}->{Crossref} = $name for (@names);
+    for (@names) {$sym->{$_}->{Crossref} = $name}
     my $sig = $sym->{$name}->{Sig};
     # diagnostic output
     print "\nFunction '".join(',',($name,@names))."'\n" if $this->{verbose};
     print "\n\tSignature: $sig\n" if defined $sig && $this->{verbose};
     $this->{CURFUNC} = $name;
   } elsif ($cmd eq 'for') {
-    $this->check_for_mode($txt,$pod_para) if $cmd eq 'for';
+    $this->check_for_mode($txt,$sep) if $cmd eq 'for';
   }
   local $this->{Parmode} = 'Body';
-  $this->SUPER::command($cmd,$txt,$line_num,$pod_para);
+  $this->SUPER::command($cmd,$txt,$sep);
 }
 
 sub check_for_mode {
-  my ($this,$txt,$pod_para) = @_;
+  my ($this,$txt,$sep) = @_;
   if ($txt =~ /^(sig|example|ref|opt|usage|bad|body)/i) {
     $this->{Parmode} = ucfirst lc $1;
     print "switched now to '$1' mode\n" if $this->{VERBOSE};
@@ -87,11 +107,10 @@ sub check_for_mode {
 }
 
 sub textblock {
-  my $this = shift;
-  my $txt = shift;
+  my ($this,$txt) = @_;
   $this->checkmode($txt);
   local $this->{INBLOCK} = 1;
-  $this->SUPER::textblock($txt,@_);
+  $this->SUPER::textblock($txt);
   $this->{Parmode} = 'Body'; # and reset parmode
 }
 
@@ -118,10 +137,9 @@ sub checkmode {
 }
 
 sub verbatim {
-  my $this = shift;
-  my $txt = shift;
+  my ($this,$txt) = @_;
   $this->checkmode($txt,1);
-  $this->SUPER::verbatim($txt,@_);
+  $this->SUPER::verbatim($txt);
 }
 
 # this needs improvement
@@ -163,29 +181,13 @@ PDL::Doc - support for PDL online documentation
 
 An implementation of online docs for PDL.
 
-=head1 Using PDL documentation
-
-PDL::Doc's main use is in the "help" (synonym "?") and "apropos"
-(synonym "??") commands in the perldl shell.  PDL::Doc provides the
-infrastrucure to index and access PDL's documentation through these
-commands.  There is also an API for direct access to the documentation 
-database (see below).
-
-The PDL doc system is built on Perl's pod (Plain Old Documentation),
-included inline with each module. The PDL core modules are
-automatically indexed when PDL is built and installed, and there is
-provision for indexing external modules as well.
-
-To include your module's pod into the Perl::Doc index, you should
-follow the documentation conventions below.  
-
 =head1 PDL documentation conventions
 
 For a package like PDL that has I<a lot> of functions it
 is very desirable to have some form of online help to
-make it easy for users to remind themselves of names,
+make it easy for the user to remind himself of names,
 calling conventions and typical usage of the multitude
-of functions at their disposal. To make it straightforward
+of functions at his disposal. To make it straightforward
 to extract the relevant information from the POD documentation
 in source files that make up the PDL distribution
 certain conventions have been adopted in formatting this
@@ -193,28 +195,39 @@ documentation.
 
 The first convention says that all documentation for
 PDL functions appears in the POD section introduced
-by one of the following:
+by
 
   =head1 FUNCTIONS
-  =head1 OPERATORS
-  =head1 METHODS
-  =head1 CONSTRUCTORS
 
-If you're documenting an object-oriented interface to a class
-that your module defines, you should use METHODS and CONSTRUCTORS
-as appropriate.  If you are simply adding functions to PDL,
-use FUNCTIONS and OPERATORS as appropriate.
-
-Individual functions or methods in these section are introduced by
+Individual functions in this section are introduced by
 
   =head2 funcname
 
-where signature is the argumentlist for a PP defined function as
-explained in L<PDL::PP>. Generally, PDL documentation is in valid POD
-format (see L<perlpod>) but uses the C<=for> directive in a
-special way. The C<=for> directive is used to flag to the PDL Pod
-parser that information is following that will be used to generate
-online help.
+=cut
+
+# XXX - I don't think this is going to work for now -
+# it garbles Pod::Parser. I am changing all occurences
+# to use =for sig for now - KGB
+
+#or
+#  =head2 funcname(signature)
+
+
+=pod
+
+where signature is the argumentlist for a PP defined function
+as explained in L<PDL::PP>. Generally, PDL documentation is in
+valid POD format (see L<perlpod>) but uses the C<=for> directive
+in a special way. The C<=for> directive is used to flag to the
+PDL Pod parser that information is following that will be used
+to generate online help.
+
+The PDL podparser is derived from the PDL::Pod::Parser class that had
+to be patched in a few places, partly to fix minor bugs, partly
+to enhance functionality for perusal by PDL::Doc. Since the PDL::Doc
+module is still experimental the patched Pod-Parser distribution is
+included with the current PDL-Doc distribution. Note that PDL::Doc
+will I<not> work correctly with the released Pod-Parser distribution.
 
 The PDL Pod parser recognises the following C<=for> directives:
 
@@ -227,7 +240,7 @@ e.g.,
 
    =for ref
 
-   Returns an ndarray of lags to parent.
+   Returns a piddle of lags to parent.
 
 =item Sig
 
@@ -275,10 +288,10 @@ gives examples of typical usage for the current function:
 
 =item Bad
 
-provides information on how the function handles bad values. The
-documentation under this directive should indicate if this function
-accepts ndarrays with bad values and under what circumstances this function
-might return ndarrays with bad values.
+provides information on how the function handles bad values (if
+C<$PDL:Config{WITH_BADVAL}> is set to 1). The intention is to
+have this information automatically created for pp-compiled
+functions, although it can be over-ridden.
 
 =back
 
@@ -291,10 +304,10 @@ the end of the current paragraph is accepted, for example:
 
   =for example
 
-         ($x,$y) = $z->func(1,3);  # this is part of the accepted info
-         $x = func($z,0,1);        # this as well
+         ($x,$y) = $a->func(1,3);  # this is part of the accepted info
+         $x = func($a,0,1);        # this as well
 
-         $x = func($c,$d);         # but this isn't
+         $x = func($a,$b);         # but this isn't
 
 To make the resulting pod documentation also easily digestible for the
 existing pod filters (pod2man, pod2text, pod2html, etc) the actual
@@ -314,7 +327,7 @@ following example (extracted from PDL/IO/Misc/misc.pd):
 
    =for ref
 
-   Read ASCII whitespaced cols from file into ndarrays efficiently.
+   Read ASCII whitespaced cols from file into piddles efficiently.
 
    If no columns are specified all are assumed
    Will optionally only process lines matching a pattern.
@@ -339,7 +352,7 @@ which is translated by, e.g, the standard C<pod2text> converter into:
 
   rcols()
 
-    Read ASCII whitespaced cols from file into ndarrays efficiently.
+    Read ASCII whitespaced cols from file into piddles efficiently.
 
     If no columns are specified all are assumed Will optionally only
     process lines matching a pattern. Can take file name or *HANDLE.
@@ -356,7 +369,7 @@ which is translated by, e.g, the standard C<pod2text> converter into:
 
 It should be clear from the preceding example that readable output
 can be obtained from this format using the standard converters and
-the reader will hopefully get a feeling how they can easily intersperse
+the reader will hopefully get a feeling how he can easily intersperse
 the special C<=for> directives with the normal POD documentation.
 
 =head2 Which directives should be contained in the documentation
@@ -366,7 +379,7 @@ start with the
 
   =head1 NAME
 
-  PDL::Modulename -- do something with ndarrays
+  PDL::Modulename -- do something with piddles
 
 section (as anyway required by C<pod2man>) since the PDL podparser
 extracts the name of the module this function belongs to from
@@ -379,7 +392,7 @@ documented along these lines should have is the I<Ref> field preceding
 a one line description of its intended functionality (suitable for
 inclusion in a concise reference card). PP defined functions (see L<PDL::PP>)
 should have a I<Sig> field stating their signature. To facilitate
-maintenance of this documentation for such functions the 'Doc' field
+maintainance of this documentation for such functions the 'Doc' field
 has been introduced into the definition of C<pp_def> (see again L<PDL::PP>)
 which will take care that name and signature of the so defined function
 are documented in this way (for examples of this usage see, for example,
@@ -410,9 +423,8 @@ alternatives.
 =cut
 
 package PDL::Doc;
-use strict;
-use warnings;
 use PDL::Core '';
+use IO::File;  # for file handles
 use File::Basename;
 use PDL::Doc::Config;
 
@@ -472,13 +484,8 @@ sub ensuredb {
     while (read IN, $plen,2) {
       my ($len) = unpack "S", $plen;
       read IN, $txt, $len;
-      my (@a) =  split chr(0), $txt;
-      my $module = splice @a,1,1;
-      push(@a, "") unless(@a % 2);  # Add null string at end if necessary -- solves bug with missing REF section.
-      my ($sym, %hash) = @a;
-     
-      $hash{Dbfile} = $fi; # keep the origin pdldoc.db path
-      $this->{SYMS}->{$sym}->{$module} = {%hash};
+      my ($sym, %hash) = split chr(0), $txt;
+      $this->{SYMS}->{$sym} = {%hash};
     }
     close IN;
     push @{$this->{Scanned}}, $fi;
@@ -496,20 +503,11 @@ with this object.
 sub savedb {
   my ($this) = @_;
   my $hash = $this->ensuredb();
-  open my $fh, '>', $this->{Outfile} or barf "can't write to symdb $this->{Outfile}: $!";
-  binmode $fh;
-  while (my ($name,$mods_hash) = each %$hash) {
-    next if 0 == scalar(%$mods_hash);
-    while (my ($module,$val) = each %$mods_hash){
-      my $fi = $val->{File};
-      if (File::Spec->file_name_is_absolute($fi) && -f $fi) {
-        #store paths to *.pm files relative to pdldoc.db
-        $val->{File} = File::Spec->abs2rel($fi, dirname($this->{Outfile})) ;
-      }
-      delete $val->{Dbfile}; # no need to store Dbfile
-      my $txt = join(chr(0),$name,$module,%$val);
-      print $fh pack("S",length($txt)).$txt;
-    }
+  open OUT, ">$this->{Outfile}" or barf "can't write to symdb $this->{Outfile}";
+  binmode OUT;
+  while (my ($key,$val) = each %$hash) {
+    my $txt = "$key".chr(0).join(chr(0),%$val);
+    print OUT pack("S",length($txt)).$txt;
   }
 }
 
@@ -518,44 +516,6 @@ sub savedb {
 
 Return the PDL symhash (e.g. for custom search operations)
 
-The symhash is a multiply nested hash ref with the following structure:
-
- $symhash = {
-     function_name => {
-             module::name => {
-                  Module => 'module::name',
-                  Sig    => 'signature string',
-                  Bad    => 'bad documentation string',
-                  ...
-                  },
-             },
-     function_name => {
-             module::name => {
-                  Module => 'module::name',
-                  Sig    => 'signature string',
-                  Bad    => 'bad documentation string',
-                  ...
-                  },
-             },
- }
-
-The three-layer structure is designed to allow the symhash (and the
-underlying database) to handle functions that have the same name but
-reside in different module namespaces.
-
-The possible keys for each function/module entry include:
-
- Module   - module name
- Sig      - signature
- Crossref - the function name for the documentation, if it has multiple
-            names (ex: the documentation for zeros is under zeroes)
- Names    - a comma-separated string of all the function's names
- Example  - example text (optional)
- Ref      - one-line reference string
- Opt      - options
- Usage    - short usage explanation
- Bad      - explanation of behavior when it encounters bad values
-
 =cut
 
 sub gethash {
@@ -574,7 +534,6 @@ Searching is by default case insensitive. Other flags can be
 given by specifying the regexp in the form C<m/regex/ismx>
 where C</> can be replaced with any other non-alphanumeric
 character. $fields is an array reference for all hash fields
-(or simply a string if you only want to search one field)
 that should be matched against the regex. Valid fields are
 
   Name,    # name of the function
@@ -582,21 +541,7 @@ that should be matched against the regex. Valid fields are
   Ref,     # the one-line reference description
   Example, # the example for this function
   Opt,     # options
-  File,    # the path to the source file these docs have been extracted from
-
-If you wish to have your results sorted by function name, pass a true
-value for C<$sort>.
-
-The results will be returned as an array of triplets in the form
-
- @results = (
-  [funcname, module, {SYMHASH_ENTRY}],
-  [funcname, module, {SYMHASH_ENTRY}],
-  ...
- );
-
-See the example at the end of the documentation to see how you might
-use this.
+  File,    # the path to the source file this docs have been extracted from
 
 =cut
 
@@ -606,24 +551,17 @@ sub search {
   $sort = 0 unless defined $sort;
   my $hash = $this->ensuredb;
   my @match = ();
-
-  # Make a single scalar $fields work
-  $fields = [$fields] if ref($fields) eq '';
-
   $pattern = $this->checkregex($pattern);
-
-  while (my ($name,$mods_hash) = each %$hash) {
-      while (my ($module,$val) = each %$mods_hash){
-	FIELD: for (@$fields) {
-	    if ($_ eq 'Name' and $name =~ /$pattern/i
-		or defined $val->{$_} and $val->{$_} =~ /$pattern/i) {
-		$val = $hash->{$val->{Crossref}}->{$module} #we're going to assume that any Crossref'd documentation is also in this module
-		if defined $val->{Crossref} && defined $hash->{$val->{Crossref}}->{$module};
-		push @match, [$name,$module,$val];
-		last FIELD;
-	    }
-	}
+  while (my ($key,$val) = each %$hash) {
+    for (@$fields) {
+      if (($_ eq 'Name' && $key =~ /$pattern/) ||
+	  (defined $val->{$_} && $val->{$_} =~ /$pattern/)) {
+	$val = $hash->{$val->{Crossref}}
+	  if defined $val->{Crossref} && defined $hash->{$val->{Crossref}};
+	push @match, [$key,$val];
+	last;
       }
+    }
   }
   @match = sort {$a->[0] cmp $b->[0]} @match if (@match && $sort);
   return @match;
@@ -635,14 +573,13 @@ sub search {
 # where the pairs of '/' can be replaced by any other pair of matching
 # characters
 # if the expression doesn't start with 'm' followed by a nonalphanumeric
-# character,  return as-is
+# character return as is
 sub checkregex {
   my ($this,$regex) = @_;
   return "(?i)$regex" unless $regex =~ /^m[^a-z,A-Z,0-9]/;
   my $sep = substr($regex,1,1);
   substr($regex,0,2) = '';
-  $sep = '(?<!\\\\)\\'.$sep; # Avoid '\' before the separator
-
+  $sep = '\\'.$sep; # quote separator just in case
   my ($pattern,$mod) = split($sep,$regex,2);
   barf "unknown regex modifiers '$mod'" if $mod && $mod !~ /[imsx]+/;
   $pattern = "(?$mod)$pattern" if $mod;
@@ -674,66 +611,59 @@ sub scan {
 
   # Now parse orig pm/pod
 
-  open my $infile, '<', $file;
+  my $infile =  new IO::File $file;
   # XXXX convert to absolute path
   # my $outfile = '/tmp/'.basename($file).'.pod';
-  open my $outfile, '>', \(my $outfile_text);
+  my $outfile = new NullHandle;
 
   # Handle RPM etc. case where we are building away from the final
   # location. Alright it's a hack - KGB
   my $file2 = $file;
-  $file2 =~ s/^$ENV{BUILDROOTPREFIX}// if $ENV{BUILDROOTPREFIX};
+  $file2 =~ s/^$ENV{BUILDROOTPREFIX}// if $ENV{BUILDROOTPREFIX} ne "";
 
-  my $parser = PDL::PodParser->new;
+  my $parser = new PDL::PodParser;
   $parser->{verbose} = $verbose;
-  eval { $parser->parse_from_filehandle($infile,$outfile) };
-  warn "cannot parse '$file' ($@)" if $@;
-
+  $parser->parse_from_filehandle($infile,$outfile);
   $this->{SYMS} = {} unless defined $this->{SYMS};
   my $hash = $this->{SYMS};
   my @stats = stat $file;
   $this->{FTIME}->{$file2} = $stats[9]; # store last mod time
   # print "mtime of $file: $stats[9]\n";
+  my $phash = $parser->{SYMHASH};
   my $n = 0;
-  while (my ($key,$val) = each %{ $parser->{SYMHASH} }) {
+  while (my ($key,$val) = each %$phash) {
+    #print "adding '$key'\n";
     $n++;
+
     $val->{File} = $file2;
-    #set up the 3-layer hash/database structure: $hash->{funcname}->{PDL::SomeModule} = $val
-    if (defined($val->{Module})){
-	$hash->{$key}->{$val->{Module}} = $val;
-    } else {
-	warn "no Module for $key in $file2\n";
+    $hash->{$key} = $val
     }
-  }
 
   # KGB pass2 - scan for module name and function
   # alright I admit this is kludgy but it works
   # and one can now find modules with 'apropos'
 
-  open $infile, '<', $file;
-  $outfile_text = '';
+  $infile =  new IO::File $file;
+  $outfile = new StrHandle;
   $parser = new PDL::PodParser;
   $parser->select('NAME');
-  eval { $parser->parse_from_filehandle($infile,$outfile) };
-  warn "cannot parse '$file'" if $@;
-
-  my @namelines = split("\n",$outfile_text);
+  $parser->parse_from_filehandle($infile,$outfile);
+  my @namelines = split("\n",$outfile->{Text});
   my ($name,$does);
   for (@namelines) {
-     if (/^(PDL) (-) (.*)/ or  /^\s*(Inline::Pdlpp)\s*(-*)?\s*(.*)\s*$/ or /\s*(PDL::[\w:]*)\s*(-*)?\s*(.*)\s*$/) {
-	$name = $1; $does = $3;
-     }
-     if (/^\s*([a-z][a-z0-9]*) (-+) (.*)/) { # lowercase shell script name
+     if (/^(PDL) (-) (.*)/ or /\s*(PDL::[\w:]*)\s*(-*)?\s*(.*)\s*$/) {
        $name = $1; $does = $3;
-       ($name,$does) = (undef,undef) unless $does =~ /shell|script/i;
+     }
+     if (/^\s*([a-z]+) (-+) (.*)/) { # lowercase shell script name
+       $name = $1; $does = $3;
+       ($name,$does) = (undef,undef) unless $does =~ /shell/i;
      }
    }
-   $does = 'Hmmm ????' if $does and $does =~ /^\s*$/;
+   $does = 'Hmmm ????' if $does =~ /^\s*$/;
    my $type = ($file =~ /\.pod$/ ? 
-	       ($does =~ /shell|script/i && $name =~ /^[a-z][a-z0-9]*$/) ? 'Script:' 
-	       : 'Manual:'
+	       ($does =~ /shell/i ? 'Script:' : 'Manual:')
 	       : 'Module:');
-   $hash->{$name}{$name} = {Ref=>"$type $does",File=>$file2} if $name and $name !~ /^\s*$/;
+   $hash->{$name} = {Ref=>"$type $does",File=>$file2} if $name !~ /^\s*$/;
    return $n;
 }
 
@@ -754,9 +684,8 @@ sub scantree {
   my $sub = sub { if (($File::Find::name =~ /[.]pm$/ &&
 		      $File::Find::name !~ /PP.pm/ &&
 		      $File::Find::name !~ m|Pod/Parser.pm| &&
-		      $File::Find::dir !~ m#/PP|/Gen#) or (
-		       $File::Find::name =~ /[.]pod$/ && 
-                       $File::Find::name !~ /Index[.]pod$/)){
+		      $File::Find::dir !~ m#/PP|/Gen#) or
+		       $File::Find::name =~ /[.]pod$/){
        printf "%-20s", $_.'...';
        my $n = $this->scan($File::Find::name,$verbose); # bind $this lexically
        print "\t$n functions\n";
@@ -771,21 +700,15 @@ sub scantree {
 =head2 funcdocs
 
 extract the complete documentation about a function from its
-source file using the PDL::PodParser filter.
+  source file using the PDL::Pod::Parser filter.
 
 =cut
 
 sub funcdocs {
-  my ($this,$func,$module,$fout) = @_;
+  my ($this,$func,$fout) = @_;
   my $hash = $this->ensuredb;
   barf "unknown function '$func'" unless defined($hash->{$func});
-  barf "funcdocs now requires 3 arguments" if defined fileno $module;
-  my $file = $hash->{$func}->{$module}->{File};
-  my $dbf = $hash->{$func}->{$module}->{Dbfile};
-  if (!File::Spec->file_name_is_absolute($file) && $dbf) {
-    $file = File::Spec->rel2abs($file, dirname($dbf)); 
-  }
-  funcdocs_fromfile($func,$file,$fout);
+  funcdocs_fromfile($func,$hash->{$func}->{File},$fout);
 }
 
 =head1 FUNCTIONS
@@ -795,168 +718,43 @@ sub funcdocs {
 sub funcdocs_fromfile {
   my ($func,$file) = @_;
   barf "can't find file '$file'" unless -f $file;
-  local $SIG{PIPE}= sub {}; # Prevent crashing if user exits the pager
-  open my $in, '<', $file or barf "can't open file $file";
-  my $out = $_[2];
-  open $out, "| pod2text | $PDL::Doc::pager" if !defined $out;
+  my $in = new IO::File $file;
+  my $out = ($#_ > 1 && defined($_[2])) ? $_[2] :
+    new IO::File "| pod2text | $PDL::Doc::pager";
+  barf "can't open file $file" unless $in;
   barf "can't open output handle" unless $out;
   getfuncdocs($func,$in,$out);
-  print $out "Docs from $file\n\n";
+
+  if (ref $out eq 'GLOB') {
+  	print $out "Docs from $file\n\n"; } else {
+	$out->print("Docs from $file\n\n"); }
 }
 
 sub extrdoc {
   my ($func,$file) = @_;
-  open my $out, '>', \(my $out_text);
+  my $out = new StrHandle;
   funcdocs_fromfile($func,$file,$out);
-  return $out_text;
+  return $out->text;
 }
 
 sub getfuncdocs {
   my ($func,$in,$out) = @_;
-  my $parser = Pod::Select->new;
-#  $parser->select("\\(METHODS\\|OPERATORS\\|CONSTRUCTORS\\|FUNCTIONS\\|METHODS\\)/$func(\\(.*\\)*\\s*");
-  foreach my $foo(qw/FUNCTIONS OPERATORS CONSTRUCTORS METHODS/) {
-      seek $in,0,0;
-      $parser->select("$foo/(.*,\\s+)*$func(\\(.*\\))*(\\s*|,\\s+.*)");
-      $parser->parse_from_filehandle($in,$out);
-  }
+  my $parser = new PDL::Pod::Parser;
+  $parser->select("FUNCTIONS/$func(\\(.*\\))*\\s*");
+  $parser->parse_from_filehandle($in,$out);
 }
 
-
-=head2 add_module
-
-=for usage
-
- use PDL::Doc; PDL::Doc::add_module("my::module");
-
-=for ref
-
-The C<add_module> function allows you to add POD from a particular Perl
-module that you've installed somewhere in @INC.  It searches for the
-active PDL document database and the module's .pod and .pm files, and
-scans and indexes the module into the database.
-
-C<add_module> is meant to be added to your module's Makefile as part of the
-installation script.
-
-=cut
-
-sub add_module {
-    my($module) = shift;
-    use File::Copy qw{copy};
-    my($pdldoc);
-    local($_);
-  DIRECTORY:
-    for my $dir (@INC){
-	my $file = $dir."/PDL/pdldoc.db";
-	if( -f $file) {
-	    if(! -w "$dir/PDL") {
-		die "No write permission at $dir/PDL - not updating docs database.\n";
-	    }
-	    print "Found docs database $file\n";
-	    $pdldoc = PDL::Doc->new($file);
-	    last DIRECTORY;
-	}
-    }
-
-    die "Unable to find docs database - therefore not updating it.\n" unless($pdldoc);
-
-    my $mfile = $module;
-    $mfile =~ s/\:\:/\//g;
-    for(@INC){
-	my $postfix;
-	my $hit = 0;
-	for $postfix(".pm",".pod") {
-	    my $f = "$_/$mfile$postfix";
-	    if( -e $f ){
-		$pdldoc->ensuredb();
-		$pdldoc->scan($f);
-		eval { $pdldoc->savedb(); };
-		warn $@ if $@;
-		print "PDL docs database updated - added $f.\n";
-		$hit = 1;
-	    }
-	}
-	return if($hit);
-    }
-
-    die "Unable to find a .pm or .pod file in \@INC for module $module\n";
-}
-
-=head1 PDL::DOC EXAMPLE
-
-Here's an example of how you might use the PDL Doc database in your
-own code.
-
- use PDL::Doc;
- # Find the pdl documentation
- my ($dir,$file,$pdldoc);
- DIRECTORY: for $dir (@INC) {
-     $file = $dir."/PDL/pdldoc.db";
-     if (-f $file) {
-         print "Found docs database $file\n";
-         $pdldoc = new PDL::Doc ($file);
-         last DIRECTORY;
-     }
- }
-
- die ("Unable to find docs database!\n") unless $pdldoc;
-
- # Print the reference line for zeroes:
- print map{$_->{Ref}} values %{$pdldoc->gethash->{zeroes}};
- # Or, if you remember that zeroes is in PDL::Core:
- print $pdldoc->gethash->{zeroes}->{PDL::Core}->{Ref};
-
- # Get info for all the functions whose examples use zeroes
- my @entries = $pdldoc->search('zeroes','Example',1);
-
- # All the functions that use zeroes in their example:
- print "Functions that use 'zeroes' in their examples include:\n";
- foreach my $entry (@entries) {
-     # Unpack the entry
-     my ($func_name, $module, $sym_hash) = @$entry;
-     print "$func_name\n";
- }
- print "\n";
-
- #Or, more concisely:
- print join("\n",map{$_->[0]}@entries);
-
- # Let's look at the function 'mpdl'
- @entries = $pdldoc->search('mpdl', 'Name');
- # I know there's only one:
- my $entry = $entries[0];
- my ($func_name, undef, $sym_hash) = @$entry;
- print "mpdl info:\n";
- foreach my $key (sort keys %$sym_hash) {
-     # Unpack the entry
-     print "---$key---\n$sym_hash->{$key}\n";
- }
-
-=head2 Finding Modules
-
-How can you tell if you've gotten a module for one of your entries?
-The Ref entry will begin with 'Module:' if it's a module. In code:
-
- # Prints:
- #  Module: fundamental PDL functionality and vectorization/broadcasting
- print $pdldoc->gethash->{'PDL::Core'}->{'PDL::Core'}->{Ref}, "\n"
+1;
 
 =head1 BUGS
 
 Quite a few shortcomings which will hopefully be fixed following
-discussions on the pdl-devel mailing list.
+discussions on the pdl-porters mailing list.
 
 =head1 AUTHOR
 
-Copyright 1997 Christian Soeller E<lt>c.soeller@auckland.ac.nzE<gt>
+Copyright 1997 Christian Soeller E<lt>c.soeller@auckland.ac.nzE<gt> 
 and Karl Glazebrook E<lt>kgb@aaoepp.aao.gov.auE<gt>
-
-Further contributions copyright 2010 David Mertens
-E<lt>dcmertens.perl@gmail.comE<gt>
-
-Documentation database restructuring 2019 Derek Lamb
-
 All rights reserved. There is no warranty. You are allowed
 to redistribute this software / documentation under certain
 conditions. For details, see the file COPYING in the PDL
