@@ -15,17 +15,11 @@
 
 use File::Find;
 use File::Basename;
-use File::Basename;
-use Getopt::Std;
+use File::Basename;                                                             
 use Pod::Html;
 use Cwd;
 
-$opt_v = 0;
-$opt_s = '';
-
-getopts('vs:');
-my $verbose = $opt_v;
-my ($strip_path,$add_path) = split(/,/,$opt_s);
+use IO::File; # for hack_links()
 
 ##############################################################
 ## Subroutines
@@ -47,68 +41,44 @@ sub mkdir_p ($$$) {
 #    my $dir = File::Spec->catdir( @dirs );
     my $dir = join '/', @dirs;
     mkdir_p ($dir, $_[1], $_[2]);
-    print "Creating directory $_[0]\n" if $verbose;
+    print "Creating directory $_[0]\n";
     mkdir $_[0], $_[1] or die "Couldn't create directory $_[0]";
 }
 
-sub fix_pdl_dot_html ($) {
-##Links to PDL.html sensibly try to go up one too many directories
-##(e.g., to "../PDL.html" instead of "PDL.html").  This hopefully
-##fixes that. Shamelessly ripped off hack_html().
+# Replace PDL/...|PDL/... with PDL/...
+# as Pod::Html v1.01 (perlv 5.005_03 )
+# doesn't seem to be able to handle
+# L<PDL::PDL|PDL::PDL> correctly
+#
+# (not necessary for perl 5.6.0)
+#
+sub hack_html ($) {
     my $infile = shift;
     my $outfile = "${infile}.n";
-    open my $ifh, "<", $infile
-	or die "ERROR: Unable to read from <$infile>: $!\n";
-    open my $ofh, ">", $outfile
-	or die "ERROR: Unable to write to <$outfile>: $!\n";
+
+    my $ifh = new IO::File "<$infile" 
+	or die "ERROR: Unable to read from <$infile>\n";
+    my $ofh = new IO::File ">$outfile" 
+	or die "ERROR: Unable to write to <$outfile>\n";
+
     # assume that links do not break across a line
     while ( <$ifh> ) {
 	# fix the links
-	s{\.\.\/PDL\.html}{PDL.html}g;
+	s{PDL/([^|]+)\|PDL/\1}{PDL/$1}g;
+	# fix the text of the link
+	s{PDL::([^|]+)\|PDL::\1}{PDL::$1}g;
+	# now fix any links for scripts
+	s{/([^|]+)\|PDL/\1}{/PDL/$1}g;
+	s{([^|]+)\|PDL::\1}{$1}g;
 	print $ofh $_;
     }
-    close $ifh;
-    close $ofh;
+    $ifh->close;
+    $ofh->close;
+
     rename $outfile, $infile
 	or die "ERROR: Unable to rename $outfile\n";
 }
 
-sub fix_html_path ($) {
-    my $infile = shift;
-    my $outfile = "${infile}.n";
-    open my $ifh, "<", $infile
-	or die "ERROR: Unable to read from <$infile>: $!\n";
-    open my $ofh, ">", $outfile
-	or die "ERROR: Unable to write to <$outfile>: $!\n";
-    # assume that links do not break across a line
-    while ( <$ifh> ) {
-	# fix the links
-	s{a href="$strip_path}{a href="$add_path}g;
-	print $ofh $_;
-    }
-    close $ifh;
-    close $ofh;
-    rename $outfile, $infile or die "ERROR: Unable to rename $outfile\n";
-}
-
-sub fix_pp_inline ($) {
-    my $infile = shift;
-    my $outfile = "${infile}.n";
-    open my $ifh, "<", $infile
-	or die "ERROR: Unable to read from <$infile>: $!\n";
-    open my $ofh, ">", $outfile
-	or die "ERROR: Unable to write to <$outfile>: $!\n";
-    # assume that links do not break across a line
-    while ( <$ifh> ) {
-	#fix the links
-	s|a href="../Inline/Pdlpp.html"|a href="./PP-Inline.html"|g;
-	print $ofh $_;
-    }
-    close $ifh;
-    close $ofh;
-    rename $outfile, $infile or die "ERROR: Unable to rename $outfile\n";
-}
-
 ##############################################################
 ## Code
 
@@ -139,40 +109,37 @@ chdir $back;
 
 #my $updir = File::Spec->updir;
 
-print "Making HTML docs...\n\n";
-
-print "Put HTML $htmldir\n" if $verbose;
-print "Scanning $startdir ... \n\n" if $verbose;
-$sub = sub {
+print "Put HTML $htmldir\n";
+print "Scanning $startdir ... \n\n";
+$sub = sub { 
     return unless $File::Find::name =~ /[.]pod$/ or
-	($File::Find::name =~ /[.]pm$/ and
-	 $File::Find::name !~ /PP.pm/  and
+	($File::Find::name =~ /[.]pm$/ and 
+	 $File::Find::name !~ /PP.pm/  and 
 	 $File::Find::dir !~ m{/PP|/Gen});
-
+    
 #    if (($File::Find::name =~ /[.]pm$/ and
 #	 $File::Find::name !~ /PP.pm/ and
 #	 $File::Find::dir !~ m#/PP|/Gen#) or
 #	 $File::Find::name =~ /[.]pod$/) {
 
     if (!&has_pod($File::Find::name)) {
-	printf STDERR "%-30s\n", $_ ."... skipped (no pod)"
-	  if $verbose;
+	printf STDERR "%-30s\n", $_ ."... skipped (no pod)";
 	return;
     }
-
+    
     my $re = "\Q$startdir\E";  # ach: '+' in $outdir here!
-
+    
     my $outdir = $File::Find::dir;
     # $outdir =~ s/$re/$htmldir/;
     $outdir =~ s/$re//;
     $outdir =~ /(^\/)?(.*)$/;
-
+    
     my $basename = basename($File::Find::name);
     my $outfi;
-
-    # Special case for needed for PDL.pm file since it is in a
+    
+    # Special case for needed for PDL.pm file since it is in a 
     # different location than the other .pm and pod files.
-    if( $basename eq 'PDL.pm'){
+    if( $basename eq 'PDL.pm'){ 
 	$outfi = $basename;
     } else {
 	$outfi = $2.($2 =~ /^\s*$/ ? '' : '/').$basename;
@@ -182,69 +149,48 @@ $sub = sub {
 	#
 	#$outfi =~ s|/|_|g;
     }
-
+    
     # create the output directory, if required
     if ( $outdir ne "" ) {
 #	    $outdir = File::Spec->catdir( $htmldir, $outdir );
 	$outdir = "${htmldir}/${outdir}";
 	mkdir_p $outdir, 0777, $outdir;
     }
-
+    
     # print "outdir = $outdir, making $outfi\n"; return;
     # mkdir_p $outdir, 0777, $outdir;
-
+    
     my $file = $File::Find::name;
 #	my $outfile = File::Spec->catfile( $htmldir, $outfi );
     my $outfile = "${htmldir}/${outfi}";
     $outfile =~ s/[.](pm|pod)$//;
     $outfile .= ".html";
-    printf STDERR "%-30s\n", $_ ."..."; #  > $outfile";
-
+    printf STDERR "%-30s\n", $_ ."... > $outfile";
+    
     chdir $htmldir; # reuse our pod caches
     my $topPerlDir = $startdir;
-
+    
     # get Directory just above PDL for podroot arg
     $topPerlDir = $1 if ($startdir =~ /^(.+?)\/PDL$/);
-    print "startdir: $startdir, podroot: $topPerlDir\n" if $verbose;
-
+    print "startdir: $startdir, podroot: $topPerlDir\n";
+    
     # instead of having htmlroot="../../.."
     # (or even File::Spec->catdir( $updir, $updir, $updir ) )
-    # calculate it from the known location of the
+    # calculate it from the known location of the 
     # file we're creating
     my $htmlrootdir = $htmldir;
     $htmlrootdir =~ s|PDL$||;
-
-    my $verbopts = $verbose ? "--verbose" : "--quiet";
-
-    my @pod2html_args = (
-      "--podpath=.",
-      "--podroot=$topPerlDir",
-      "--htmldir=$htmlrootdir",
-      "--recurse",
-      "--infile=$file",
-      "--outfile=$outfile",
-      $verbopts,
-    );
-    if($] <= 5.015) {
-      # With perl 5.15.x (for some value of x) and later, '--libpods' is invalid
-      # and hence needs to be removed.
-      # Beginning with 5.15.x, the generated PDL html docs are a little different
-      # (missing some underlining of headings and some <b></b> tagging), though
-      # this appears to have nothing to do with the removal of --libpods. Rather,
-      # it seems to be the result of some other change to pod2html. Perhaps this
-      # can be addressed over time. SIS 23-Feb-2012
-      # Cut out "PDL" from the podpath as it crashes the podscan(!) - It doesn't
-      # seem to help either -- it looks for cached docs in .../HtmlDocs/pdl/PDL,
-      # which is silly.  I left this note because pod paths are pretty arcane to
-      # me.  CED 11-Mar-2009
-      #    pod2html("--podpath=PDL:.",
-      unshift @pod2html_args, "--libpods=perlfaq";
-    }
-    pod2html(@pod2html_args);
-    fix_pdl_dot_html( $outfile);
-    fix_html_path( $outfile);
-    fix_pp_inline( $outfile);
-
+    
+    pod2html("--podpath=PDL:.",
+	     "--podroot=$topPerlDir",
+	     "--htmlroot=$htmlrootdir",
+	     "--libpods=perlfaq",
+	     "--recurse",
+	     "--infile=$file",
+	     "--outfile=$outfile",
+	     "--verbose");
+    hack_html( $outfile ) if $] < 5.006;
+    
     chdir $File::Find::dir; # don't confuse File::Find
 };
 
