@@ -4,17 +4,17 @@
 
 =head1 NAME
 
-PDL::Graphics::PGPLOT - PGPLOT enhanced interface for PDL
+  PDL::Graphics::PGPLOT - PGPLOT enhanced interface for PDL
 
 =head1 SYNOPSIS
 
- pdl> $x = pdl [1..100]
- pdl> $y = sqrt($x)
- pdl> line $y
- pdl> hold
+ perldl> $a = pdl [1..100]
+ perldl> $b = sqrt($a)
+ perldl> line $b
+ perldl> hold
  Graphics on HOLD
- pdl> $c = sin($x/10)*2 + 4
- pdl> line $c
+ perldl> $c = sin($a/10)*2 + 4
+ perldl> line $c
 
 =head1 DESCRIPTION
 
@@ -28,19 +28,16 @@ The list of currently availably commands:
 
  imag       -  Display an image (uses pgimag()/pggray() as appropriate)
  im         -  Shorthand to display an image with aspect ratio of 1
- fits_imag  -  Display a FITS image with appropriate transforms & labels
- cont       -  Display image as contour map
- fits_cont  -  Display a FITS image in scientific coordinates as a contour map
- vect       -  Display 2 images as a vector field
- fits_vect  -  Display 2 FITS images in sci. coordinates as a vector field
  ctab       -  Load an image colour table
  ctab_info  -  Get information about currently loaded colour table
  line       -  Plot vector as connected points
  points     -  Plot vector as points
  errb       -  Plot error bars
+ cont       -  Display image as contour map
  bin        -  Plot vector as histogram (e.g. bin(hist($data)) )
  hi2d       -  Plot image as 2d histogram (not very good IMHO...)
  poly       -  Draw a polygon
+ vect       -  Display 2 images as a vector field
  text       -  Write text in the plot area
  label_axes -  Print axis titles
  legend     -  Create a legend with different texts, linestyles etc.
@@ -58,7 +55,7 @@ Device manipulation commands:
  dev          -  Explicitly set a new PGPLOT graphics device
  new_window   -  Create a new plot window (use of dev is recommended)
  focus_window -  Change focus to a new window
- window_list  -  Get a list of currently existing plot windows
+ window_list  -  Get a list of currently exisiting plot windows
  close_window -  Close an open window
 
 
@@ -88,7 +85,7 @@ C<focus_window> to select the window.
 The result of this command can be modified using options. The options
 recognised are the same as for C<new_window> - which primarily and in
 addition it is possible to set the default values for a window that are
-defined in L<PDL::Graphics::PGPLOTOptions>, see this for details but see below for
+defined in L<PDL::PGPLOTOptions>, see this for details but see below for
 a synopsis.
 
 In addition C<dev> recognises the option C<NewWindow> which allows the
@@ -146,10 +143,7 @@ package PDL::Graphics::PGPLOT;
 use PDL::Core qw/:Func :Internal/; # Grab the Core names
 use PDL::Graphics::PGPLOTOptions qw(default_options);
 use PDL::Graphics::PGPLOT::Window;
-BEGIN {
-  eval { require PGPLOT; PGPLOT->import; 1 }
-    or die "Dependency on PGPLOT is not satisfied: $@";
-}
+use PGPLOT;
 use Exporter;
 
 use strict;
@@ -158,14 +152,11 @@ use vars qw (@ISA @EXPORT);
 
 @ISA = ('Exporter');
 
-@EXPORT = qw( dev hold release rel env bin errb line points
-	      fits_imag imag imag1 fits_cont cont fits_vect vect
-	      draw_wedge ctab ctab_info hi2d poly CtoF77coords
+@EXPORT = qw( dev hold release rel env bin cont errb line points
+	      imag imag1 draw_wedge ctab ctab_info hi2d poly vect CtoF77coords
 	      new_window focus_window window_list close_window
 	      label_axes text legend cursor circle ellipse rectangle
-	      tpoints tline retrieve_state replay turn_off_recording
-	      turn_on_recording clear_state autolog get_current_window
-              transform
+	      tpoints tline
 	    );
 
 *rel = *release;		# Alias
@@ -227,10 +218,10 @@ Open a PGPLOT graphics device
 
   $win = new_window($dev, $nx, $ny, $opt);
 
-This function is identical to L</dev> except that it always creates a new
+This function is identical to L<dev> except that it always creates a new
 window. This means that the user is required to close all windows
-explicitly using L</close_window>. All functionality is otherwise like C<dev>
-so see the documentation for L</dev> for details of use.
+explicitly using L<close_window>. All functionality is otherwise like C<dev>
+so see the documentation for L<dev> for details of use.
 
 =cut
 
@@ -293,7 +284,7 @@ C<new_window>. It requires the id of the window to close. If C<$id> is
 left undefined, the currently focussed window is deleted and focus is
 transferred to the lowest numbered window in existence. If many windows
 have been created and deleted this might not be what you expect, so
-it is recommended to make an explicit call to L</focus_window> after
+it is recommended to make an explicit call to L<focus_window> after
 any call to C<close_window>.
 
 =cut
@@ -368,7 +359,7 @@ sub _get_windownumber {
       $windownumber = $name;
     } else {
       print "Valid window names: \n";
-      foreach my $k (sort keys %_WINDOWNAMES) {
+      foreach my $k (keys %_WINDOWNAMES) {
 	print "$k\n";
       }
       barf ("I cannot switch to window $name - no such name\n");
@@ -429,7 +420,7 @@ Switch to another output window.
  Usage: focus_window($id);
 
 This command is used to switch output focus to another window created by
-L</dev> or L</new_window>. The window can be referred to either by its
+L<dev> or L<new_window>. The window can be referred to either by its
 ID or by its name.
 
 =for example
@@ -461,7 +452,7 @@ sub focus_window {
 =for ref
 
 Return a list of ID numbers and names of the windows currently opened using
-L</dev> or L</new_window>.
+L<dev> or C<new_window>.
 
 =for usage
 
@@ -476,7 +467,7 @@ names of the open windows respectively.
 sub window_list {
   my @numbers=();
   my @names=();
-  foreach (sort keys %_WINDOWNAMES) {
+  foreach (keys %_WINDOWNAMES) {
     if (ref($_WINDOWNAMES{$_}) eq 'PDL::Graphics::PGPLOT::Window') {
       push @names, $_;
     } else {
@@ -493,51 +484,73 @@ sub label_axes {
   $CW->label_axes(@_);
 }
 
-sub turn_on_recording {
-  if (!defined($CW)) {
-    warn "You can only turn on recording when you have a device open!\n";
-    return;
-  }
-  $CW->turn_on_recording();
-}
-
-sub turn_off_recording {
-  if (!defined($CW)) {
-    warn "You can only turn off recording when you have a device open!\n";
-    return;
-  }
-  $CW->turn_off_recording();
-}
-
-sub retrieve_state {
-  if (!defined($CW)) {
-    warn "You can only retrieve the state when a device is open\n";
-    return;
-  }
-  $CW->retrieve_state();
-}
-
-
-sub replay {
-  if (!defined($CW)) {
-    warn "You can only replay plotting commands when a device is open!\n";
-    return;
-  }
-  $CW->replay(@_);
-}
-
-sub clear_state {
-  if (!defined($CW)) {
-    warn "You can only clear the state when a device is open\n";
-    return;
-  }
-  $CW->clear_state();
-}
-
-
-sub autolog { # for this one we use the class method to set autolog globally
+sub env {
   dev() if !defined($CW);
-  PDL::Graphics::PGPLOT::Window->autolog(@_);
+  $CW->env(@_);
+}
+sub bin {
+  dev() if !defined($CW);
+  $CW->bin(@_);
+}
+sub cont {
+  dev() if !defined($CW);
+  $CW->cont(@_);
+}
+sub errb {
+  dev() if !defined($CW);
+  $CW->errb(@_);
+}
+sub line {
+  dev() if !defined($CW);
+  $CW->line(@_);
+}
+sub tline {
+  dev() if !defined($CW);
+  $CW->tline(@_);
+}
+sub points {
+  dev() if !defined($CW);
+  $CW->points(@_);
+}
+sub tpoints {
+  dev() if !defined($CW);
+  $CW->tpoints(@_);
+}
+sub imag {
+  dev() if !defined($CW);
+  $CW->imag(@_);
+}
+sub imag1 {
+  dev() if !defined($CW);
+  $CW->imag1(@_);
+}
+sub draw_wedge {
+  barf 'Open a plot window first!' if !defined($CW);
+  $CW->draw_wedge(@_);
+}
+sub ctab {
+  dev() if !defined($CW);
+  $CW->ctab(@_);
+}
+sub ctab_info {
+  dev() if !defined($CW);
+  $CW->ctab_info(@_);
+}
+sub hi2d {
+  dev() if !defined($CW);
+  $CW->hi2d(@_);
+}
+sub poly {
+  dev() if !defined($CW);
+  $CW->poly(@_);
+}
+sub vect {
+  dev() if !defined($CW);
+  $CW->vect(@_);
+}
+sub CtoF77coords {
+  dev() if !defined($CW);
+  $CW->CtoF77coords(@_);
 }
 
 sub text {
@@ -555,22 +568,19 @@ sub legend {
   $CW->legend(@_);
 }
 
-# should add these routines to EXPORT array as we create
-# each routine
-#
-foreach my $func (
-		  qw(
-		     env bin cont fits_cont errb line tline points tpoints
-		     imag fits_imag imag1 draw_wedge 
-		     ctab ctab_info hi2d poly vect fits_vect
-		     CtoF77coords circle ellipse rectangle 
-		     ) ) {
-    eval <<"ENDOFFUNC";
-sub $func {
-    dev() if !defined(\$CW);
-    \$CW->${func}(\@_);
+sub circle {
+  dev(@_) if !defined($CW);
+  $CW->circle(@_);
 }
-ENDOFFUNC
+
+sub ellipse {
+  dev(@_) if !defined($CW);
+  $CW->ellipse(@_);
+}
+
+sub rectangle {
+  dev(@_) if !defined($CW);
+  $CW->rectangle(@_);
 }
 
 sub transform {
@@ -583,7 +593,6 @@ sub release { return if !defined($CW); $CW->release(); print "Graphics RELEASED\
 #sub held { return 0 if !defined($CW); return $CW->held()};
 #sub current_device { return $CW->device(); };
 
-sub get_current_window { return $CW; }  # return current window or undef if none exists
 
 1;				# Exit with OK status
 
