@@ -40,7 +40,6 @@ package PDL::Graphics::TriD::VRML;
 use PDL::Core '';  # barf
 use PDL::Graphics::VRML;
 use PDL::LiteF;
-use PDL::Config;
 PDL::Graphics::VRMLNode->import();
 PDL::Graphics::VRMLProto->import();
 
@@ -305,11 +304,11 @@ sub PDL::Graphics::TriD::Image::vdraw {
 sub PDL::Graphics::TriD::Graph::tovrml {
 	my($this) = @_;
 	my @children = ();
-	for(sort keys %{$this->{Axis}}) {
+	for(keys %{$this->{Axis}}) {
 		if($_ eq "Default") {next}
 		push @children, @{$this->{Axis}{$_}->tovrml_axis($this)};
 	}
-	for(sort keys %{$this->{Data}}) {
+	for(keys %{$this->{Data}}) {
 	    push @children,
 	     $this->{Data}{$_}->tovrml_graph($this,$this->get_points($_));
 	}
@@ -385,9 +384,7 @@ sub PDL::Graphics::TriD::SimpleController::tovrml {
 }
 
 
-package #split this line so the
-        # CPAN indexer doesn't complain
-        Win32;
+package Win32;
 
 sub Win32::fn_win32_format {
   my ($file) = @_;
@@ -396,8 +393,7 @@ sub Win32::fn_win32_format {
   return $file;
 }
 
-package # hide from PAUSE
-    Win32::DDE::Netscape;
+package Win32::DDE::Netscape;
 use PDL::Core '';  # barf
 require Win32::DDE::Client if $^O =~ /win32/i;
 
@@ -432,7 +428,10 @@ use PDL::Core '';  # barf
 
 sub new {
   my ($type,%hash) = @_;
-  bless {Mode => 'VRML', %hash},$type;
+  my $this = bless {},$type;
+  $this->{Mode} = 'VRML';
+  for (keys %hash) { $this->{$_} = $hash{$_} }
+  return $this;
 }
 
 sub gifmode {
@@ -447,7 +446,7 @@ sub vrmlmode {
 
 sub set {
   my ($this,%hash) = @_;
-  @$this{keys %hash} = values %hash;
+  for (keys %hash) { $this->{$_} = $hash{$_} }
   return $this;
 }
 
@@ -520,7 +519,6 @@ sub send_to_browser {my $this=$_[0]; &{$this->{'Browser'}}(@_)
 
 package PDL::Graphics::TriD::VRML::URL;
 use PDL::Core '';  # barf
-require File::Temp;
 
 my %types = (
 	     'image/JPG' => {'save' => sub {local $PDL::debug=0; $_[1]->wpic($_[0]->wfile)},
@@ -538,8 +536,8 @@ sub new {
   $this->{'Type'} = $types{$mime};
   &{$this->{'Type'}->{'setup'}} if defined $this->{'Type'}->{'setup'};
   $this->{'Binding'} = 'local';
-  $this->{'Filestem'} = File::Temp::tempdir(CLEANUP=>1) . "/tridim_$urlnum";
-  $urlnum++;
+  $this->{'Filestem'} = ($ENV{'TMP'} || $ENV{'TEMP'} || '/tmp') .
+    "/tridim_$urlnum"; $urlnum++;
   return $this;
 }
 
@@ -567,7 +565,7 @@ $PDL::Graphics::TriD::create_window_sub = sub {
 };
 
 # set up the default parameters for VRML
-my $tmpdir = File::Temp::tempdir(CLEANUP=>1);
+my $tmpdir = $ENV{'TMP'} || $ENV{'TEMP'} || '/tmp';
 my $tmpname = "$tmpdir/tridvrml_$$.wrl";
 my $para = $PDL::Graphics::TriD::Settings =
   PDL::Graphics::TriD::VRML::Parameter->new() ;
@@ -607,11 +605,11 @@ use strict;
 sub gdriver {
   my($this) = @_;
 
-  require PDL if not defined $PDL::VERSION;
+  require PDL::Version if not defined $PDL::Version::VERSION;
   $this->{Width} = 300; $this->{Height} = 300;
   $this->{VRMLTop} = new PDL::Graphics::VRML("\"PDL::Graphics::TriD::VRML Scene\"",
 				  ["\"generated by the PDL::Graphics::TriD module\"",
-				   "\"version $PDL::VERSION\""]);
+				   "\"version $PDL::Version::VERSION\""]);
   my $fontstyle = new PDL::Graphics::VRMLNode('FontStyle',
 				    'size' => 0.04,
 				    'family' => "\"SANS\"",
